============================
Contributing to development
============================

As any non-cave-dwelling developer knows, working on a project alone sucks.
Collaboration inspires new ideas, leads to better code, and increases the
longevity of a project. I welcome feedback, suggestions, and contributions from
other developers. Please submit bug reports, feedback, and suggestions on the
`github issue tracker <https://github.com/androomerrill/scikit-nano/issues>`_.
To contribute to development, fork the project on github and send me a pull
request. Thanks!
